Welcome to the ACStore documentation
====================================

ACStore, or Attribute Container Storage, provides a stand-alone implementation
to read and write attribute container storage files.

The source code is available from the `project page <https://github.com/log2timeline/acstore>`__.

.. toctree::
   :maxdepth: 2

   sources/user/index

.. toctree::
   :maxdepth: 2

   API documentation <sources/api/acstore>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

